@@ -1,19 +1,21 @@
 """
+Client
+==============
 Provides the main interface classes for the Strava version 3 REST API.
 """
-from __future__ import division, absolute_import, print_function, unicode_literals
+
+import json
 import logging
-import warnings
 import functools
 import time
 import collections
 import calendar
+import warnings
 from io import BytesIO
 from datetime import datetime, timedelta
 
 import arrow
 import pytz
-import six
 
 from units.quantity import Quantity
 
@@ -23,34 +25,40 @@ from stravalib.util import limiter
 from stravalib import unithelper
 
 
+warnings.simplefilter('default')
+logging.captureWarnings(True)
+
+
 class Client(object):
     """
     Main client class for interacting with the exposed Strava v3 API methods.
 
     This class can be instantiated without an access_token when performing authentication;
     however, most methods will require a valid access token.
+
     """
 
-    def __init__(self, access_token=None, rate_limit_requests=True,
-                 rate_limiter=None, requests_session=None):
+    def __init__(self,
+                 access_token=None,
+                 rate_limit_requests=True,
+                 rate_limiter=None,
+                 requests_session=None):
         """
         Initialize a new client object.
 
-        :param access_token: The token that provides access to a specific Strava account.  If empty, assume that this
-                             account is not yet authenticated.
-        :type access_token: str
-
-        :param rate_limit_requests: Whether to apply a rate limiter to the requests. (default True)
-        :type rate_limit_requests: bool
-
-        :param rate_limiter: A :class:`stravalib.util.limiter.RateLimiter' object to use.
-                             If not specified (and rate_limit_requests is True), then
-                             :class:`stravalib.util.limiter.DefaultRateLimiter' will
-                             be used.
-        :type rate_limiter: callable
-
-        :param requests_session: (Optional) pass request session object.
-        :type requests_session: requests.Session() object
+        Parameters
+        ----------
+        access_token : str
+            The token that provides access to a specific Strava account. If empty, assume that this
+            account is not yet authenticated.
+        rate_limit_requests : bool
+            Whether to apply a rate limiter to the requests. (default True)
+        rate_limiter : callable
+            A :class:`stravalib.util.limiter.RateLimiter` object to use.
+            If not specified (and rate_limit_requests is True), then
+            :class:`stravalib.util.limiter.DefaultRateLimiter` will be used.
+        requests_session : requests.Session() object
+            (Optional) pass request session object.
 
         """
         self.log = logging.getLogger('{0.__module__}.{0.__name__}'.format(self.__class__))
@@ -79,33 +87,36 @@ class Client(object):
         """
         self.protocol.access_token = v
 
-    def authorization_url(self, client_id, redirect_uri, approval_prompt='auto',
-                          scope=None, state=None):
+    def authorization_url(self,
+                          client_id,
+                          redirect_uri,
+                          approval_prompt='auto',
+                          scope=None,
+                          state=None):
         """
         Get the URL needed to authorize your application to access a Strava user's information.
 
         See https://developers.strava.com/docs/authentication/
 
-        :param client_id: The numeric developer client id.
-        :type client_id: int
+        Parameters
+        ----------
+        client_id : int
+            The numeric developer client id.
+        redirect_uri : str
+            The URL that Strava will redirect to after successful (or failed) authorization.
+        approval_prompt : str
+            Whether to prompt for approval even if approval already granted to app.
+            Choices are 'auto' or 'force'.  (Default is 'auto')
+        scope : list[str]
+            The access scope required.  Omit to imply "read" and "activity:read"
+            Valid values are 'read', 'read_all', 'profile:read_all', 'profile:write', 'activity:read',
+            'activity:read_all', 'activity:write'.
+        state : str
+            An arbitrary variable that will be returned to your application in the redirect URI.
 
-        :param redirect_uri: The URL that Strava will redirect to after successful (or failed) authorization.
-        :type redirect_uri: str
-
-        :param approval_prompt: Whether to prompt for approval even if approval already granted to app.
-                                Choices are 'auto' or 'force'.  (Default is 'auto')
-        :type approval_prompt: str
-
-        :param scope: The access scope required.  Omit to imply "read" and "activity:read"
-                      Valid values are 'read', 'read_all', 'profile:read_all', 'profile:write', 'profile:read_all',
-                      'activity:read_all', 'activity:write'.
-        :type scope: list[str]
-
-        :param state: An arbitrary variable that will be returned to your application in the redirect URI.
-        :type state: str
-
-        :return: The URL to use for authorization link.
-        :rtype: str
+        Returns
+        -------
+        string : The URL string to use for authorization link.
         """
         return self.protocol.authorization_url(client_id=client_id,
                                                redirect_uri=redirect_uri,
@@ -117,18 +128,19 @@ class Client(object):
         Exchange the temporary authorization code (returned with redirect from strava authorization URL)
         for a short-lived access token and a refresh token (used to obtain the next access token later on).
 
-        :param client_id: The numeric developer client id.
-        :type client_id: int
+        Parameters
+        ----------
+        client_id : int
+            The numeric developer client id.
+        client_secret : str
+            The developer client secret
+        code : str
+            The temporary authorization code
 
-        :param client_secret: The developer client secret
-        :type client_secret: str
-
-        :param code: The temporary authorization code
-        :type code: str
-
-        :return: Dictionary containing the access_token, refresh_token
-                 and expires_at (number of seconds since Epoch when the provided access token will expire)
-        :rtype: dict
+        Returns
+        -------
+        Dictionary containing the access_token, refresh_token
+        and expires_at (number of seconds since Epoch when the provided access token will expire)
         """
         return self.protocol.exchange_code_for_token(client_id=client_id,
                                                      client_secret=client_secret,
@@ -139,18 +151,19 @@ class Client(object):
         Exchanges the previous refresh token for a short-lived access token and a new
         refresh token (used to obtain the next access token later on).
 
-        :param client_id: The numeric developer client id.
-        :type client_id: int
+        Parameters
+        ----------
+        client_id : int
+            The numeric developer client id.
+        client_secret : str
+            The developer client secret
+        refresh_token : str
+            The refresh token obtained from a previous authorization request
 
-        :param client_secret: The developer client secret
-        :type client_secret: str
-
-        :param refresh_token: The refresh token obtained from a previous authorization request
-        :type refresh_token: str
-
-        :return: Dictionary containing the access_token, refresh_token
-                 and expires_at (number of seconds since Epoch when the provided access token will expire)
-        :rtype: dict
+        Returns
+        -------
+        Dictionary containing the access_token, refresh_token
+        and expires_at (number of seconds since Epoch when the provided access token will expire)
         """
         return self.protocol.refresh_access_token(client_id=client_id,
                                                   client_secret=client_secret,
@@ -161,7 +174,7 @@ class Client(object):
         Deauthorize the application. This causes the application to be removed
         from the athlete's "My Apps" settings page.
 
-        See http://strava.github.io/api/v3/oauth/#deauthorization
+        https://developers.strava.com/docs/authentication/#deauthorization
         """
         self.protocol.post("oauth/deauthorize")
 
@@ -169,10 +182,15 @@ class Client(object):
         """
         Convert the specified datetime value to a unix epoch timestamp (seconds since epoch).
 
-        :param activity_datetime: A string which may contain tzinfo (offset) or a datetime object (naive datetime will
-                                    be considered to be UTC).
-        :return: Epoch timestamp.
-        :rtype: int
+        Parameters
+        ----------
+        activity_datetime : str
+            A string which may contain tzinfo (offset) or a datetime object (naive datetime will
+            be considered to be UTC).
+
+        Returns
+        -------
+        Epoch timestamp in int format.
         """
         if isinstance(activity_datetime, str):
             activity_datetime = arrow.get(activity_datetime).datetime
@@ -186,7 +204,7 @@ class Client(object):
         """
         Get activities for authenticated user sorted by newest first.
 
-        http://strava.github.io/api/v3/activities/
+        https://developers.strava.com/docs/reference/#api-Activities-getLoggedInAthleteActivities
 
 
         :param before: Result will start with activities whose start date is
@@ -220,34 +238,28 @@ class Client(object):
                                       result_fetcher=result_fetcher,
                                       limit=limit)
 
-    def get_athlete(self, athlete_id=None):
+    def get_athlete(self):
         """
         Gets the specified athlete; if athlete_id is None then retrieves a
         detail-level representation of currently authenticated athlete;
         otherwise summary-level representation returned of athlete.
 
-        http://strava.github.io/api/v3/athlete/#get-details
+        https://developers.strava.com/docs/reference/#api-Athletes
 
-        http://strava.github.io/api/v3/athlete/#get-another-details
+        https://developers.strava.com/docs/reference/#api-Athletes-getLoggedInAthlete
 
         :return: The athlete model object.
         :rtype: :class:`stravalib.model.Athlete`
         """
-        if athlete_id is None:
-            raw = self.protocol.get('/athlete')
-        else:
-            raise NotImplementedError("The /athletes/{id} endpoint was removed by Strava.  "
-                                      "See https://developers.strava.com/docs/january-2018-update/")
-
-            # raw = self.protocol.get('/athletes/{athlete_id}', athlete_id=athlete_id)
-
+        raw = self.protocol.get('/athlete')
         return model.Athlete.deserialize(raw, bind_client=self)
 
+    # TODO: this endpoint was removed so do we want to remove the URL altogether?
     def get_athlete_friends(self, athlete_id=None, limit=None):
         """
         Gets friends for current (or specified) athlete.
 
-        http://strava.github.io/api/v3/follow/#friends
+        https://developers.strava.com/docs/reference/#api-models-DetailedAthlete
 
         :param: athlete_id
         :type: athlete_id: int
@@ -276,7 +288,7 @@ class Client(object):
         """
         Updates the properties of the authorized athlete.
 
-        http://strava.github.io/api/v3/athlete/#update
+        https://developers.strava.com/docs/reference/#api-Athletes-updateLoggedInAthlete
 
         :param city: City the athlete lives in
         :param state: State the athlete lives in
@@ -302,8 +314,6 @@ class Client(object):
         """
         Gets followers for current (or specified) athlete.
 
-        http://strava.github.io/api/v3/follow/#followers
-
         :param: athlete_id
         :type athlete_id: int
 
@@ -332,7 +342,7 @@ class Client(object):
         Retrieve the athletes who both the authenticated user and the indicated
          athlete are following.
 
-        http://strava.github.io/api/v3/follow/#both
+        This endpoint was removed by Strava in Jan 2018.
 
         :param athlete_id: The ID of the other athlete (for follower intersection with current athlete)
         :type athlete_id: int
@@ -354,14 +364,13 @@ class Client(object):
         #                               result_fetcher=result_fetcher,
         #                               limit=limit)
 
+    # TODO: Can't find this in the api documentation either. Does it still work?
     def get_athlete_koms(self, athlete_id, limit=None):
         """
         Gets Q/KOMs/CRs for specified athlete.
 
         KOMs are returned as `stravalib.model.SegmentEffort` objects.
 
-        http://strava.github.io/api/v3/athlete/#koms
-
         :param athlete_id: The ID of the athlete.
         :type athlete_id: int
 
@@ -387,7 +396,7 @@ class Client(object):
         If it is left blank two requests will be made - first to get the
         authenticated athlete's id and second to get the Stats.
 
-        http://strava.github.io/api/v3/athlete/#stats
+        https://developers.strava.com/docs/reference/#api-Athletes-getStats
 
         :return: A model containing the Stats
         :rtype: :py:class:`stravalib.model.AthleteStats`
@@ -405,7 +414,7 @@ class Client(object):
         """
         List the clubs for the currently authenticated athlete.
 
-        http://strava.github.io/api/v3/clubs/#get-athletes
+        https://developers.strava.com/docs/reference/#api-Clubs-getLoggedInAthleteClubs
 
         :return: A list of :class:`stravalib.model.Club`
         :rtype: :py:class:`list`
@@ -437,7 +446,7 @@ class Client(object):
         """
         Return a specific club object.
 
-        http://strava.github.io/api/v3/clubs/#get-details
+        https://developers.strava.com/docs/reference/#api-Clubs-getClubById
 
         :param club_id: The ID of the club to fetch.
         :type club_id: int
@@ -451,7 +460,7 @@ class Client(object):
         """
         Gets the member objects for specified club ID.
 
-        http://strava.github.io/api/v3/clubs/#get-members
+        https://developers.strava.com/docs/reference/#api-Clubs-getClubMembersById
 
         :param club_id: The numeric ID for the club.
         :type club_id: int
@@ -473,7 +482,7 @@ class Client(object):
         """
         Gets the activities associated with specified club.
 
-        http://strava.github.io/api/v3/clubs/#get-activities
+        https://developers.strava.com/docs/reference/#api-Clubs-getClubActivitiesById
 
         :param club_id: The numeric ID for the club.
         :type club_id: int
@@ -497,7 +506,7 @@ class Client(object):
 
         Will be detail-level if owned by authenticated user; otherwise summary-level.
 
-        http://strava.github.io/api/v3/activities/#get-details
+        https://developers.strava.com/docs/reference/#api-Activities-getActivityById
 
         :param activity_id: The ID of activity to fetch.
         :type activity_id: int
@@ -507,6 +516,10 @@ class Client(object):
         :type include_all_efforts: bool
 
         :rtype: :class:`stravalib.model.Activity`
+
+        TODO: contrary to the Strava API documentation, this endpoint _always_
+        returns all segment efforts when the include_all_efforts parameter is provided,
+        regardless its value
         """
         raw = self.protocol.get('/activities/{id}', id=activity_id,
                                 include_all_efforts=include_all_efforts)
@@ -514,9 +527,7 @@ class Client(object):
 
     def get_friend_activities(self, limit=None):
         """
-        Gets activities for friends (of currently authenticated athlete).
-
-        http://strava.github.io/api/v3/activities/#get-feed
+        DEPRECATED This endpoint was removed by Strava in Jan 2018.
 
         :param limit: Maximum number of activities to return. (default unlimited)
         :type limit: int
@@ -588,11 +599,11 @@ class Client(object):
 
     def update_activity(self, activity_id, name=None, activity_type=None,
                         private=None, commute=None, trainer=None, gear_id=None,
-                        description=None,device_name=None):
+                        description=None, device_name=None, hide_from_home=None):
         """
         Updates the properties of a specific activity.
 
-        http://strava.github.io/api/v3/activities/#put-updates
+        https://developers.strava.com/docs/reference/#api-Activities-updateActivityById
 
         :param activity_id: The ID of the activity to update.
         :type activity_id: int
@@ -609,6 +620,7 @@ class Client(object):
         :param gear_id: Alpha-numeric ID of gear (bike, shoes) used on this activity.
         :param description: Description for the activity.
         :param device_name: Device name for the activity
+        :param hide_from_home: Whether the activity is muted (hidden from Home and Club feeds).
 
         :return: The updated activity.
         :rtype: :class:`stravalib.model.Activity`
@@ -639,20 +651,24 @@ class Client(object):
 
         if description is not None:
             params['description'] = description
-            
+
         if device_name is not None:
             params['device_name'] = device_name
+        
+        if hide_from_home is not None:
+            params['hide_from_home'] = int(hide_from_home)
 
         raw_activity = self.protocol.put('/activities/{activity_id}', activity_id=activity_id, **params)
 
         return model.Activity.deserialize(raw_activity, bind_client=self)
 
     def upload_activity(self, activity_file, data_type, name=None, description=None,
-                        activity_type=None, private=None, external_id=None):
+                        activity_type=None, private=None, external_id=None, trainer=None,
+                        commute=None):
         """
         Uploads a GPS file (tcx, gpx) to create a new activity for current athlete.
 
-        http://strava.github.io/api/v3/athlete/#get-details
+        https://developers.strava.com/docs/reference/#api-Uploads-createUpload
 
         :param activity_file: The file object to upload or file contents.
         :type activity_file: file or str
@@ -671,16 +687,27 @@ class Client(object):
                               nordicski, alpineski, backcountryski, iceskate, inlineskate,
                               kitesurf, rollerski, windsurf, workout, snowboard, snowshoe
                               Type detected from file overrides, uses athlete's default type if not specified
+                              WARNING - This param is supported (as of 2022-11-15), but not
+                              documented and may be removed in the future.
         :type activity_type: str
 
-        :param private: (optional) set to True to mark the resulting activity as private, 'view_private' permissions will be necessary to view the activity
+        :param private: (optional) set to True to mark the resulting activity as private,
+                        'view_private' permissions will be necessary to view the activity.
+                        WARNING - This param is not supported by the Strava API and may be
+                        removed in the future.
         :type private: bool
 
         :param external_id: (optional) An arbitrary unique identifier may be specified which will be included in status responses.
         :type external_id: str
+
+        :param trainer: (optional) Whether the resulting activity should be marked as having been performed on a trainer.
+        :type trainer: bool
+
+        :param commute: (optional) Whether the resulting activity should be tagged as a commute.
+        :type commute: bool
         """
         if not hasattr(activity_file, 'read'):
-            if isinstance(activity_file, six.string_types):
+            if isinstance(activity_file, str):
                 activity_file = BytesIO(activity_file.encode('utf-8'))
             elif isinstance(activity_file, str):
                 activity_file = BytesIO(activity_file)
@@ -697,13 +724,29 @@ class Client(object):
         if description is not None:
             params['description'] = description
         if activity_type is not None:
+            warnings.warn(
+                'The "activity_type" parameter is undocumented in the Strava API. Its use '
+                'may lead to unexpected behavior or errors in the future.',
+                FutureWarning,
+                stacklevel=2
+            )
             if not activity_type.lower() in [t.lower() for t in model.Activity.TYPES]:
                 raise ValueError("Invalid activity type: {0}.  Possible values: {1!r}".format(activity_type, model.Activity.TYPES))
             params['activity_type'] = activity_type
         if private is not None:
+            warnings.warn(
+                'The "private" parameter is unsupported by the Strava API. It has no '
+                'effect and may lead to errors in the future',
+                DeprecationWarning,
+                stacklevel=2
+            )
             params['private'] = int(private)
         if external_id is not None:
             params['external_id'] = external_id
+        if trainer is not None:
+            params['trainer'] = json.dumps(trainer)
+        if commute is not None:
+            params['commute'] = json.dumps(commute)
 
         initial_response = self.protocol.post('/uploads',
                                               files={'file': activity_file},
@@ -712,11 +755,12 @@ class Client(object):
 
         return ActivityUploader(self, response=initial_response)
 
+    # TODO: I don't think this is the correct link but can't find it in the docs
     def delete_activity(self, activity_id):
         """
         Deletes the specified activity.
 
-        https://strava.github.io/api/v3/activities/#delete
+        https://developers.strava.com/docs/reference/#api-Activities
 
         :param activity_id: The activity to delete.
         :type activity_id: int
@@ -729,7 +773,7 @@ class Client(object):
 
         Requires premium account.
 
-        http://strava.github.io/api/v3/activities/#zones
+        https://developers.strava.com/docs/reference/#api-Activities-getZonesByActivityId
 
         :param activity_id: The activity for which to zones.
         :type activity_id: int
@@ -745,7 +789,7 @@ class Client(object):
         """
         Gets the comments for an activity.
 
-        http://strava.github.io/api/v3/comments/#list
+        https://developers.strava.com/docs/reference/#api-Activities-getCommentsByActivityId
 
         :param activity_id: The activity for which to fetch comments.
         :type activity_id: int
@@ -771,7 +815,7 @@ class Client(object):
         """
         Gets the kudos for an activity.
 
-        http://strava.github.io/api/v3/kudos/#list
+        https://developers.strava.com/docs/reference/#api-Activities-getKudoersByActivityId
 
         :param activity_id: The activity for which to fetch kudos.
         :type activity_id: int
@@ -791,11 +835,12 @@ class Client(object):
                                       result_fetcher=result_fetcher,
                                       limit=limit)
 
+    # TODO not sure this is the correct api doc link - couldn't find "photos"
     def get_activity_photos(self, activity_id, size=None, only_instagram=False):
         """
         Gets the photos from an activity.
 
-        http://strava.github.io/api/v3/photos/
+        https://developers.strava.com/docs/reference/#api-Activities
 
         :param activity_id: The activity for which to fetch photos.
         :type activity_id: int
@@ -830,7 +875,7 @@ class Client(object):
         """
         Gets the laps from an activity.
 
-        http://strava.github.io/api/v3/activities/#laps
+        https://developers.strava.com/docs/reference/#api-Activities-getLapsByActivityId
 
         :param activity_id: The activity for which to fetch laps.
         :type activity_id: int
@@ -848,9 +893,7 @@ class Client(object):
 
     def get_related_activities(self, activity_id, limit=None):
         """
-        Returns the activities that were matched as 'with this activity'.
-
-        http://strava.github.io/api/v3/activities/#get-related
+        Deprecated. This endpoint was removed by strava in Jan 2018.
 
         :param activity_id: The activity for which to fetch related activities.
         :type activity_id: int
@@ -874,7 +917,7 @@ class Client(object):
         """
         Get details for an item of gear.
 
-        http://strava.github.io/api/v3/gear/#show
+        https://developers.strava.com/docs/reference/#api-Gears
 
         :param gear_id: The gear id.
         :type gear_id: str
@@ -888,7 +931,7 @@ class Client(object):
         """
         Return a specific segment effort by ID.
 
-        http://strava.github.io/api/v3/efforts/#retrieve
+        https://developers.strava.com/docs/reference/#api-SegmentEfforts
 
         :param effort_id: The id of associated effort to fetch.
         :type effort_id: int
@@ -903,7 +946,7 @@ class Client(object):
         """
         Gets a specific segment by ID.
 
-        http://strava.github.io/api/v3/segments/#retrieve
+        https://developers.strava.com/docs/reference/#api-SegmentEfforts-getSegmentEffortById
 
         :param segment_id: The segment to fetch.
         :type segment_id: int
@@ -919,7 +962,7 @@ class Client(object):
         Returns a summary representation of the segments starred by the
          authenticated user. Pagination is supported.
 
-        http://strava.github.io/api/v3/segments/#starred
+        https://developers.strava.com/docs/reference/#api-Segments-getLoggedInAthleteStarredSegments
 
         :param limit: (optional), limit number of starred segments returned.
         :type limit: int
@@ -940,12 +983,14 @@ class Client(object):
                                       result_fetcher=result_fetcher,
                                       limit=limit)
 
+    # TODO: i'm not sure what the diff is between this method and the one above
+    # So i used the SAME API doc link for both. may need to revisit
     def get_athlete_starred_segments(self, athlete_id, limit=None):
         """
         Returns a summary representation of the segments starred by the
          specified athlete. Pagination is supported.
 
-        http://strava.github.io/api/v3/segments/#starred
+        https://developers.strava.com/docs/reference/#api-Segments-getLoggedInAthleteStarredSegments
 
         :param athlete_id: The ID of the athlete.
         :type athlete_id: int
@@ -965,14 +1010,13 @@ class Client(object):
                                       result_fetcher=result_fetcher,
                                       limit=limit)
 
+    # TODO find the new equavilent link in the strava docs
     def get_segment_leaderboard(self, segment_id, gender=None, age_group=None, weight_class=None,
                                 following=None, club_id=None, timeframe=None, top_results_limit=None,
                                 page=None, context_entries = None):
         """
         Gets the leaderboard for a segment.
 
-        http://strava.github.io/api/v3/segments/#leaderboard
-
         Note that by default Strava will return the top 10 results, and if the current user has ridden
         that segment, the current user's result along with the two results above in rank and the two
         results below will be included.  The top X results can be configured by setting the top_results_limit
@@ -1081,7 +1125,7 @@ class Client(object):
         for a segment in San Francisco, CA can be fetched using
         2014-01-01T00:00:00Z and 2014-01-01T23:59:59Z.
 
-        http://strava.github.io/api/v3/segments/#all_efforts
+        https://developers.strava.com/docs/reference/#api-SegmentEfforts-getEffortsBySegmentId
 
         :param segment_id: ID of the segment.
         :type segment_id: param
@@ -1110,12 +1154,12 @@ class Client(object):
             params['athlete_id'] = athlete_id
 
         if start_date_local:
-            if isinstance(start_date_local, six.string_types):
+            if isinstance(start_date_local, str):
                 start_date_local = arrow.get(start_date_local).naive
             params["start_date_local"] = start_date_local.strftime("%Y-%m-%dT%H:%M:%SZ")
 
         if end_date_local:
-            if isinstance(end_date_local, six.string_types):
+            if isinstance(end_date_local, str):
                 end_date_local = arrow.get(end_date_local).naive
             params["end_date_local"] = end_date_local.strftime("%Y-%m-%dT%H:%M:%SZ")
 
@@ -1133,7 +1177,7 @@ class Client(object):
         """
         Returns an array of up to 10 segments.
 
-        http://strava.github.io/api/v3/segments/#explore
+        https://developers.strava.com/docs/reference/#api-Segments-exploreSegments
 
         :param bounds: list of bounding box corners lat/lon [sw.lat, sw.lng, ne.lat, ne.lng] (south,west,north,east)
         :type bounds: list of 4 floats or list of 2 (lat,lon) tuples
@@ -1176,11 +1220,11 @@ class Client(object):
     def get_activity_streams(self, activity_id, types=None,
                              resolution=None, series_type=None):
         """
-        Returns an streams for an activity.
+        Returns a stream for an activity.
 
-        http://strava.github.io/api/v3/streams/#activity
+        https://developers.strava.com/docs/reference/#api-Streams-getActivityStreams
 
-        Streams represent the raw data of the uploaded file. External
+        Streams represent the raw spatial data for the uploaded file. External
         applications may only access this information for activities owned
         by the authenticated athlete.
 
@@ -1191,8 +1235,6 @@ class Client(object):
         Streams types are: time, latlng, distance, altitude, velocity_smooth,
                            heartrate, cadence, watts, temp, moving, grade_smooth
 
-        http://strava.github.io/api/v3/streams/#activity
-
         :param activity_id: The ID of activity.
         :type activity_id: int
 
@@ -1244,7 +1286,7 @@ class Client(object):
         """
         Returns an streams for an effort.
 
-        http://strava.github.io/api/v3/streams/#effort
+        https://developers.strava.com/docs/reference/#api-Streams-getSegmentEffortStreams
 
         Streams represent the raw data of the uploaded file. External
         applications may only access this information for activities owned
@@ -1257,8 +1299,6 @@ class Client(object):
         Streams types are: time, latlng, distance, altitude, velocity_smooth,
                            heartrate, cadence, watts, temp, moving, grade_smooth
 
-        http://strava.github.io/api/v3/streams/#effort
-
         :param effort_id: The ID of effort.
         :type effort_id: int
 
@@ -1308,7 +1348,7 @@ class Client(object):
         """
         Returns an streams for a segment.
 
-        http://strava.github.io/api/v3/streams/#segment
+        https://developers.strava.com/docs/reference/#api-Streams-getSegmentStreams
 
         Streams represent the raw data of the uploaded file. External
         applications may only access this information for activities owned
@@ -1321,8 +1361,6 @@ class Client(object):
         Streams types are: time, latlng, distance, altitude, velocity_smooth,
                            heartrate, cadence, watts, temp, moving, grade_smooth
 
-        http://strava.github.io/api/v3/streams/#effort
-
         :param segment_id: The ID of segment.
         :type segment_id: int
 
@@ -1365,50 +1403,12 @@ class Client(object):
 
         # Pack streams into dictionary
         return {i.type: i for i in streams}
-    
-    def get_running_race(self, race_id):
-        """
-        Gets a running race for a given identifier.t
-
-        http://strava.github.io/api/v3/running_races/#list
-
-        :param race_id: id for the race
-
-        :rtype: :class:`stravalib.model.RunningRace`
-        """        
-        raw = self.protocol.get('/running_races/{id}', id=race_id)
-        return model.RunningRace.deserialize(raw, bind_client=self)
-    
-    
-    def get_running_races(self, year=None):
-        """
-        Gets a running races for a given year.
-
-        http://strava.github.io/api/v3/running_races/#list
-
-        :param year: year for the races (default current)
-        
-        :return: An iterator of :class:`stravalib.model.RunningRace` objects.
-        :rtype: :class:`BatchedResultsIterator`
-        """
-        if year is None:
-            year = datetime.datetime.now().year
-    
-        params = {"year": year}
-
-        result_fetcher = functools.partial(self.protocol.get,
-                                           '/running_races',
-                                           **params)
-
-        return BatchedResultsIterator(entity=model.RunningRace, bind_client=self,
-                                      result_fetcher=result_fetcher)
-        
 
     def get_routes(self, athlete_id=None, limit=None):
         """
         Gets the routes list for an authenticated user.
 
-        http://strava.github.io/api/v3/routes/#list
+        https://developers.strava.com/docs/reference/#api-Routes-getRoutesByAthleteId
 
         :param athlete_id: id for the
 
@@ -1435,7 +1435,7 @@ class Client(object):
 
         Will be detail-level if owned by authenticated user; otherwise summary-level.
 
-        https://strava.github.io/api/v3/routes/#retreive
+        https://developers.strava.com/docs/reference/#api-Routes-getRouteById
 
         :param route_id: The ID of route to fetch.
         :type route_id: int
@@ -1449,21 +1449,17 @@ class Client(object):
         """
         Returns streams for a route.
 
-        http://strava.github.io/api/v3/streams/#routes
-
         Streams represent the raw data of the saved route. External
         applications may access this information for all public routes and for
-        the private routes of the authenticated athlete.
+        the private routes of the authenticated athlete. The 3 available route
+        stream types `distance`, `altitude` and `latlng` are always returned.
 
-        The 3 available route stream types `distance`, `altitude` and `latlng`
-        are always returned.
+        See: https://developers.strava.com/docs/reference/#api-Streams-getRouteStreams
 
-        http://strava.github.io/api/v3/streams/#routes
+        :param route_id: The ID of activity.
+        :type route_id: int
 
-        :param activity_id: The ID of activity.
-        :type activity_id: int
-
-        :return: A dictionary of :class:`stravalib.model.Stream`from the route.
+        :return: A dictionary of :class:`stravalib.model.Stream` from the route.
         :rtype: :py:class:`dict`
 
         """
@@ -1478,13 +1474,13 @@ class Client(object):
         # Pack streams into dictionary
         return {i.type: i for i in streams}
 
+    # TODO: removed old link to create a subscription but can't find new equiv
+    # in current strava docs
     def create_subscription(self, client_id, client_secret, callback_url,
                             verify_token=model.Subscription.VERIFY_TOKEN_DEFAULT):
         """
         Creates a webhook event subscription.
 
-        http://strava.github.io/api/partner/v3/events/#create-a-subscription
-
         :param client_id: application's ID, obtained during registration
         :type client_id: int
 
@@ -1533,12 +1529,11 @@ class Client(object):
         """
         return model.SubscriptionUpdate.deserialize(raw, bind_client=self)
 
+    # TODO can't find a api doc link here so just removed old link.
     def list_subscriptions(self, client_id, client_secret):
         """
         List current webhook event subscriptions in place for the current application.
 
-        http://strava.github.io/api/partner/v3/events/#list-push-subscriptions
-
         :param client_id: application's ID, obtained during registration
         :type client_id: int
 
@@ -1555,12 +1550,11 @@ class Client(object):
                                       bind_client=self,
                                       result_fetcher=result_fetcher)
 
+    # TODO can't find a api doc link here so just removed old link.
     def delete_subscription(self, subscription_id, client_id, client_secret):
         """
         Unsubscribe from webhook events for an existing subscription.
 
-        http://strava.github.io/api/partner/v3/events/#delete-a-subscription
-
         :param subscription_id: ID of subscription to remove.
         :type subscription_id: int
 
@@ -1626,7 +1620,7 @@ class BatchedResultsIterator(object):
 
     def _fill_buffer(self):
         """
-        Fills the internal size-50 buffer from Strava API.
+        Fills the internal buffer from Strava API.
         """
         # If we cannot fetch anymore from the server then we're done here.
         if self._all_results_fetched:
