@@ -1,20 +1,19 @@
 """
+Protocol
+==============
 Low-level classes for interacting directly with the Strava API webservers.
 """
-from __future__ import division, absolute_import, print_function, unicode_literals
 import abc
 import logging
 import functools
 
 import requests
-import six
-from six.moves.urllib.parse import urlunsplit, urljoin, urlencode
+from urllib.parse import urlunsplit, urljoin, urlencode
 
 from stravalib import exc
 
 
-@six.add_metaclass(abc.ABCMeta)
-class ApiV3(object):
+class ApiV3(metaclass=abc.ABCMeta):
     """
     This class is responsible for performing the HTTP requests, rate limiting, and error handling.
     """
@@ -64,7 +63,7 @@ class ApiV3(object):
         :type approval_prompt: str
 
         :param scope: The access scope required.  Omit to imply "read" and "activity:read"
-                      Valid values are 'read', 'read_all', 'profile:read_all', 'profile:write', 'profile:read_all',
+                      Valid values are 'read', 'read_all', 'profile:read_all', 'profile:write', 'activity:read',
                       'activity:read_all', 'activity:write'.
         :type scope: list[str]
 
@@ -77,7 +76,7 @@ class ApiV3(object):
         assert approval_prompt in ('auto', 'force')
         if scope is None:
             scope = ['read', 'activity:read']
-        elif isinstance(scope, (six.text_type, six.binary_type)):
+        elif isinstance(scope, (str, bytes)):
             scope = [scope]
 
         unsupported = set(scope) - {'read', 'read_all',
@@ -161,7 +160,7 @@ class ApiV3(object):
 
         return access_info
 
-    def _resolve_url(self, url):
+    def resolve_url(self, url):
         if not url.startswith('http'):
             url = urljoin('https://{0}'.format(self.server), self.api_base + '/' + url.strip('/'))
         return url
@@ -188,7 +187,7 @@ class ApiV3(object):
         :return: The parsed JSON response.
         :rtype: Dict[str,Any]
         """
-        url = self._resolve_url(url)
+        url = self.resolve_url(url)
         self.log.info("{method} {url!r} with params {params!r}".format(method=method, url=url, params=params))
         if params is None:
             params = {}
@@ -207,7 +206,7 @@ class ApiV3(object):
 
         raw = requester(url, params=params)
         # Rate limits are taken from HTTP response headers
-        # https://strava.github.io/api/#rate-limiting
+        # https://developers.strava.com/docs/rate-limits/
         self.rate_limiter(raw.headers)
 
         if check_for_errors:
